import {request} from '../utils/request.js'
function getDiseaseList(data){ //获取检测疾病分类列表
  return request('/basic/detection/disease','GET',data,true)
};
function getLocation(data){ //上报用户地址
  return request('/user/location','POST',data)
};
function getProjectList(data){ //获取合作公司检测项目列表
  return request('/patient/detection/project','GET',data)
};
function getProject(id){ //获取合作公司检测项目
  return request('/patient/detection/project/'+id,'GET',{},true)
};
function getDoctorList(data){ //获取检测机构合作医生列表
  return request('/patient/detection/doctor','GET',data)
};
// function getDoctorList(data){ //获取检测机构合作医生列表
//   return request('/patient/detection/doctor','GET',data)
// };
function getPurposeList(data){ //获取检测项目用途列表
  return request('/patient/detection/project/purpose','GET',data)
};
function createDetection(data){ //创建检测订单
  return request('/patient/detection','POST',data)
};
function detectionList(data){ //获取患者检测订单列表
  return request('/patient/order/detection','GET',data)
};
function detectionDetail(id){ //获取患者检测订单详情
  return request('/patient/order/detection/'+id,'GET',{})
};
function bindCheck(id,data){ //上报用户地址
  return request('/patient/detection/bind/'+id,'PUT',data,true)
};
function cancelCheckPay(id){ //取消支付
  return request('/patient/order/detection/cancel-pay/'+id,'PUT')
};
function cancelCheckOrder(id){ //取消支付
  return request('/patient/order/detection/cancel/'+id,'PUT')
};
function delCheckOrder(id){
  return request('/patient/order/detection/'+id,'DELETE')
};
function hasCreate(data){
  return request('/patient/detection','GET',data)
}
function getArea(){ //获取用户地址
  return request('/user/location','GET')
}
function checkInquiry(id){ //创建检测问诊订单
  return request('/patient/detection/inquiry/'+id,'POST',{},true)
}
module.exports={
  checkInquiry,
  getArea,
  hasCreate,
  cancelCheckOrder,
  delCheckOrder,
  cancelCheckPay,
  getDiseaseList,
  getLocation,
  getProjectList,
  getProject,
  getDoctorList,
  getPurposeList,
  createDetection,
  detectionList,
  detectionDetail,
  bindCheck
}

